7 Top Stocks to Buy for 2015 (AAPL, FB, GOOG, GOOGL, QCOM, SEAS, TSM, WWAV)
Author: Motley Fool Staff
Description: Qualcomm, Facebook, Apple, and -- surprise! -- SeaWorld Entertainment are on this Foolish list of top stocks to buy for 2015. - Motley Fool Staff - Tech and Telecom
Date: 2014-12-22T20:15:00-05:00

Welcome!

- Premium Advice
  - My Services
  - None
  - Other Services
  - Fool One
  - Hidden Gems
  - Income Investor
  - Inside Value
  - MDP Deep Value
  - Million Dollar Portfolio
  - Motley Fool Options
  - Motley Fool Pro
  - Rule Breakers
  - Rule Your Retirement
  - Special Ops
  - Stock Advisor
  - Supernova

Help Join Now or Login

### My Watchlist

Track the companies that matter to you. It's FREE! Click one of these fan favorites to get started: Apple; Google; Ford.
Email Print

Recs

### 46

# 7 Top Stocks to Buy for 2015

By Motley Fool Staff | More Articles
December 22, 2014 | Comments (25)

Need a reason to invest in stocks? How about the beginning of a new year. To help you find solid stock ideas we asked Fool.com contributors covering technology and consumer goods stocks to talk about top stocks for 2015. Read on to see what they had to say about Qualcomm (NASDAQ: QCOM ) , Facebook (NASDAQ: FB ) , SeaWorld Entertainment (NYSE: SEAS ) , WhiteWave Foods (NYSE: WWAV ) , Google (NASDAQ: GOOG ) (NASDAQ: GOOGL ) , Taiwan Semiconductor (NYSE: TSM ) , and Apple (NASDAQ: AAPL ) .

Ashraf Eassa (Qualcomm): It's hard not to be pleased with the performances of technology and, in particular, semiconductor stocks in 2014. The Philadelphia Semiconductor Index is up over 28% year-to-date, handily crushing the S&P 500 and the Nasdaq, up 10.12% and 12.73%, respectively. However, one high-quality chip company that has underperformed pretty significantly during 2014 -- but one that I believe is set to do much better in 2015 -- is Qualcomm.

First, Qualcomm's execution in developing and delivering a compelling range of mobile applications processor offerings looks unmatched. For example, the company revealed on Dec. 11 that it would be upgrading the baseband on its upcoming high-end Snapdragon 810 processor to offer 50% greater download speeds than had been previously announced. This further extends the company's leadership position in cellular baseband technology.

It's this kind of execution in its chip business that not only keeps it ahead of major competitors like MediaTek, but also makes it very difficult for mobile device vendors to successfully develop their own in-house chip solutions in a bid to cut Qualcomm out.

Further, Qualcomm's technology licensing business, which collects royalties on most 3G/4G devices sold, is extremely profitable and should continue to grow with overall smartphone growth. Now, it's well-known that Qualcomm is having issues collecting on royalties from some Chinese handset vendors (leading to pessimism around the business), but I think Qualcomm will be able to solve its issues there, as it has done in the past.

All told, Qualcomm stock is cheap at just 16.36 times trailing-12-month earnings, it's a high-quality company, but the stock has underperformed during 2014. Qualcomm the company is a winner, and I think that during 2015, Qualcomm the stock will be, too.

Andrés Cardenal (Google): Information is power and Google's mission statement, "to organize the world's information and make it universally accessible and useful" says a lot about the company and the role it plays in times of chaotically abundant information.

Google is the undisputed king in online search; the company has a bigger market share than all its competitors combined. In addition, Google has built a massive portfolio of services and applications, including enormously valuable assets like Gmail, YouTube, and Chrome, to name a few remarkable examples. More than 80% of smartphones around the planet are powered by Android, so Google is in a position of strength to continue thriving under the mobile paradigm.

The company generates tons of cash flows from its leadership position in online advertising, and management is not shy at all when it comes to investing that money in the search for breakthrough innovations. From self-driving cars to biotechnology solutions to fighting human aging and associated diseases, Google has plenty of exciting projects with disruptive potential in its pipeline.

Investors are getting concerned about slowing revenue growth and rising expenses lately, and this may provide a buying opportunity in the online search giant. Google trades at a forward P/E ratio near 17.5, roughly in line with the S&P 500 Index. However, even during a "disappointing" third quarter, Google delivered a big increase of 20% in revenues, a level of performance which most companies in the index can only envy. Google has a lot of things going right and I think Google is a top stock to consider buying for 2015.

Tamara Walsh (WhiteWave Foods): From smart acquisitions to promising opportunities in oversees markets such as China, WhiteWave Foods is one of my favorite stock picks heading into the new year. The packaged food and beverage company has enjoyed a nice run this year with the stock up more than 47% year-to-date. However, there should be plenty of growth ahead thanks to WhiteWave's partnership with Mengniu Dairy, one of China's largest dairy companies.

Image source: whitewave.com

As part of this joint venture, WhiteWave purchased a production facility where it plans to begin manufacturing its products for the Chinese market in the coming months. WhiteWave Foods owns a 49% stake in the deal, which will enable the company to sell its brands in China, one of the world's largest consumer markets with over 1.3 billion consumers and a rapidly growing middle class. Market-leading brands including Silk soy milk and almond milk, Land-o-Lakes butter, and International Delight coffee creamers, have already helped WhiteWave Foods make a name for itself in North America and Europe. The company celebrated a record third quarter recently, with net sales climbing 35% to $857 million in the period. I expect this momentum to carry over into the new year, and for the stock to continue to gain speed in the year ahead as the company expands into new markets and product categories.

Rick Munarriz (SeaWorld Entertainment): I'm going to go full contrarian with a stock that everybody seems to hate. SeaWorld is in a bad spot these days. Activists have succeeded in keeping guests away from its marine life theme parks given the negative publicity about killer whales in captivity. Attendance across its 11 parks fell 4.1% in 2013 and is off by another 4.7% through the first nine months of 2014. This is the only theme park or regional amusement park operator that's experiencing lower turnstile clicks this year. The stock that went public at $27 early in 2013 is now all the way down to the mid-teens, and earlier this month it announced that it would have to postpone the dividend that was supposed to go out in December because it would violate its debt covenants.

Image source: SeaWorld

This all seems pretty grim, but changes are coming. SeaWorld's CEO is leaving in January, opening the door for an outsider who can help soften the battered brand. Along the way we have some favorable trends including an improving economy and lower gas prices that should deliver big boosts to the theme park industry in general.

SeaWorld is in a bad spot, but it's also important to remember that just three of its parks are orca-housing SeaWorld attractions. The dividend should return in January, and guests will eventually follow as the chain either takes active steps to improve its image or fickle consumers move on to a new cause. With SeaWorld trading at a valuation discount to its peers there's plenty of upside in 2015 even if the market doesn't comply. The climate is ripe for SeaWorld to make a big splash in the year ahead.

Dylan Lewis (Apple): It's far from a sexy pick, but most who have bet against Apple the past five years have come to regret it and I don't see 2015 being any different.

Apple's brand cachet and customer loyalty hasn't wavered -- while the company's iPad line is faltering, Macs are selling well. In October the company revealed the segment posted its highest quarterly market share since 1995.

Apple's brand prestige is even more valuable in the increasingly competitive smartphone market as Asian OEM's Xiaomi, Lenovo, and Huawei continue to produce low-cost devices. Skeptics need to look no further than Samsung's shrinking smartphone market share to appreciate the moat Apple enjoys due to its status, quality, and exclusive iOS and Mac operating systems.

The recent December sell-off gives investors an even more attractive entry point, the company still trades at a TTM P/E of 17 and a forward P/E of 14.

Even in the neighborhood of some of the more conservative analyst estimates of 5 million to 10 million units, the Apple Watch could provide a 1%-3% lift on projected revenue for CY 2015. The fledgling Apple Pay now supports credit cards that comprise 90% of the U.S. credit card purchase volume and could prove to be an even bigger catalyst than the new line of wearables. With each e-commerce security breach (it seems like there's one almost every other week), Apple Pay's tokenization system becomes increasingly appealing to consumers seeking security.

Stability with its hardware stalwarts, new growth opportunities, a decent dividend yield (1.7%) and an average of $11 billion in stock repurchases each quarter for the past year and a half – there are simply too many reasons to ignore the Mac maker in 2015.

Tim Brugger (Facebook): With its stock price up 38% so far this year, it may seem counterintuitive to include Facebook on a list of stocks to buy in 2015. However, there are a laundry list of revenue opportunities at Facebook's fingertips heading into the new year, and it appears a couple in particular are about ready to pay off.

Though Twitter is loath to admit the importance of the milestone, the news that Instagram recently topped 300 million monthly active users (MAUs) is significant, to say the least. Perhaps most impressive is how quickly Instagram's MAUs grew. The number was hovering around 200 million users just nine months ago. No wonder Twitter's envious.

Facebook COO Sheryl Sandberg made waves earlier this year when she said that there was no rush to monetize Instagram in any meaningful way, nor incorporate video spots as an advertising medium. Instead, Sandberg and CEO Mark Zuckerberg wanted to grow Instagram's user base, ensure a positive user experience, and test the video ad waters -- at a whopping cost of $1 million a day -- before making them available to its marketing partners. The MAU growth of Instagram is certainly there, and with the advent of video ads on both Facebook and Instagram, 2015 should be yet another banner year.

Sean O’Reilly (Taiwan Semiconductor): Technology can be a tough business to be in for investors. The relentless competition and constant need to innovate frequently make long-term shareholder gains elusive. However, Taiwan Semiconductor not only dominates its market but happens to be leveraged to an increasingly important technological trend making it my top stock pick for 2015.

Taiwan Semiconductor is the world’s largest fabricator of silicon chips. The company pioneered the dedicated semiconductor foundry model and operates primarily by partnering with fabless customers that don’t have the scale and operating expertise that Taiwan Semiconductor possesses. Cost advantage and scale are the name of the game and these happen to be things that Taiwan Semiconductor has in spades. These advantages will become all the more apparent as the world’s need for semiconductor chips grows exponentially in the coming years.

As the world becomes more and more connected (a trend called the “Internet of Things”), Taiwan Semiconductor stands to benefit in a big way. Technology research organization Gartner estimates that 4.9 billion connected “things” will be in use in 2015, up from 3.75 billion in 2014. Gartner’s estimate for 2020? Try 25 billion connected devices. Investors have two ways to participate in this increasingly connected world: Focus on those that produce the connected devices, or the companies that make connecting these devices to the internet possible, like Taiwan Semiconductor.

There’s a lot to like on Taiwan Semi’s balance sheet and income statement as well. The company trades for just under 14 times this year’s estimated EPS according to S&P Capital IQ estimates (high for a semiconductor fabricator but more than fair given its dominant industry position) and has a pristine balance sheet with very little debt. Add in the company’s exceptional return on equity, which has averaged 23.62% over the last five years and you get a company that should be on every Foolish investor's holiday wish list.

1 great stock to buy for 2015 and beyond
2015 is shaping up to be another great year for stocks. But if you want to make sure that 2015 is your best investing year ever, you need to know where to start. That's why The Motley Fool's chief investment officer just published a brand-new research report that reveals his top stock for the year ahead. To get the full story on this year's stock -- completely free -- simply click here.

Read/Post Comments (25) | Recommend This Article (46)

Email Print Feedback
Email Print

### Comments from our Foolish Readers

Help us keep this a respectfully Foolish area! This is a place for our readers to discuss, debate, and learn more about the Foolish investing topic you read about above. Help us keep it clean and safe. If you believe a comment is abusive or otherwise violates our Fool's Rules, please report it via the Report this Comment icon found on every comment.

- ###### Report this Comment On December 23, 2014, at 10:07 PM, argusdc wrote:

  "Activists have succeeded in keeping guests away from its marine life theme parks given the negative publicity about killer whales in captivity"

  I'm sorry--the cruelty to orcas in captivity is well documented in the documentary Blackfish and employees are less than honest to the public about the health problems these mammals suffer. Consumers are not being 'fickle' here--they are responding here to inhumane treatment of orcas at SeaWorld, which is now a sinking ship.

- ###### Report this Comment On December 23, 2014, at 10:41 PM, SuntanIronMan wrote:

  Given that Cedar Fair trades at a similar earnings multiple, pays a dividend, and isn't subject to animal rights activism, I have a hard time choosing SeaWorld as a possible investment.

  I not really interested in Cedar Fair either, but if I was interested in an amusement/theme park operator, I couldn't really see myself choosing SeaWorld when there are many other options to choose from (including Disney).

- ###### Report this Comment On December 25, 2014, at 9:57 AM, papsrus wrote:

  Rick Munarriz writes:

  "... Activists have succeeded in keeping guests away from its marine life theme parks given the negative publicity about killer whales in captivity."

  and

  " ... guests will eventually follow as the chain either takes active steps to improve its image or fickle consumers move on to a new cause."

  That pretty much says it all as far as your stand on animal cruelty.

  "Activists" have not kept paying customers away from Sea World. The exposure of Sea World's own practices is what is keeping paying customers away.

  And you repeatedly use the term "guests" when what you really mean is "paying customer." A guest is someone I welcome into my home with a cozy embrace. I don't charge them a fee at the door. Your warm and fuzzy language and dismissal of "fickle consumers" doesn't mask what's really going on here.

  You also did not mention in your "investment thesis" that animal rights activists have been accumulating shares in the company in order to try to have some greater say in the matter, although I'm sure you were aware of it (or should have been before recommending the stock).

  I wouldn't bet the farm that the issue of Sea World's well-documented mistreatment of animals (and, incidentally, their apparent lethal disregard for the safety of animal trainers as well) simply recedes into our feeble collective memory as "fickle consumers" find more cash to spend on entertainment.

  A weak investment thesis for a company that is unattractive on so many levels.

  Disappointed.

- ###### Report this Comment On December 25, 2014, at 10:28 AM, AaronRogers wrote:

  WAH WAH WAH you cry baby no place for money matter replies are pathetic and wasted reading. Investing and making money has nothing to do with your moral values which I strongly disagree with anyways. For the record does anyone care about most the species going extinct. NO. Know why because the population has no experience or knowledge of their existence nor plight. Sea world brings a much needed conciousnes. Anyways Love the Sea World theory and full heartedly agree with it. Are they going bankrupt? Will they returm to stronger profitability? They are priced for bad bad times. Unless they go belly up they soar. Perfect homerun swing pick.

  The awful pick is White Wave. They have a forecasted declining growth rates with a greater than 3x P:E to growth rate multiple. This stock is way ahead of itsself. How much more can you possibly see in a climate of economic slowdown. Awful. Pick. Borderline pathetic.

  As to the rest of the picks - REALLY! Can you be more boring. Can you be more bland. Can you be less insightful. Facebook, google, etc... At best these stocks all do well. But this article was BEST STOCKS! Pick ones your readers don't know. Pick ones your readers can learn and research about like White whatever. Pick ones that have a chance to trounce not match the S&P. Atleast white whatever and Sea World have a chance to be the best. All the rest will not even place in the top 20 percent this year. Not the top 30 either. PATHETIC!

- ###### Report this Comment On December 26, 2014, at 12:03 AM, papsrus wrote:

  "WAH WAH WAH you cry baby no place for money matter replies are pathetic and wasted reading. ..."

  You should be commended for attempting to learn a second language. Keep up the hard work.

- ###### Report this Comment On December 26, 2014, at 12:21 PM, EnigmaDude wrote:

  Guess it depends on how you define "top stocks" for 2015. Does that mean the ones that will perform the best in terms of % share price increase? Or best time to invest for the long term?

  My picks for top stocks in terms of % change in share price include Opko Health (OPK), Cadiz (CDZI), and a couple of cheap energy stocks like Encana (ECA).

  Do your own research, and make constructive comments. Happy new year, Fools!

- ###### Report this Comment On December 26, 2014, at 3:21 PM, clematisclem wrote:

  "Investing and making money has nothing to do with your moral values..."

  ...to you. Warren Buffett advised investors to invest in companies that they believe in. I do not believe in SeaWorld's practices, and judging by the falling attendance, many others similarly do not. As a result of falling revenues due to people making other entertainment choices based at least in part on their moral values, Sea World's stock price has declined and the dividend was delayed. Obviously making money and moral values are not always separate issues.

- ###### Report this Comment On December 27, 2014, at 1:14 AM, AaronRogers wrote:

  LOL yeah tell that to constellation investors and their 48% this year. I'd have never guessed that for an over priced stock. And I commend those that were and drank the kool aid. Enjoy buying some stock in UNICEF. Sea World is a great pick for an article. Might go bad. But if his theory is right he trounces. Great read. Great idea. That was my point originally. You dont have to agree w his pick but that is what due diligence and personal risk tolerances are for.

  Apple...Yeah dude great call. What kind of run can that have? Long term all tech stocks are bad for the other commentor. Pick 1 long term that has rewarded investors...congrats you named a few. Look at the fail list. BTW- most investors in apple are on that one (remember when it went to 7).

- ###### Report this Comment On December 28, 2014, at 5:19 PM, TMFHamFoolery wrote:

  @enigmadude...best to invest for the long-term. Even through the end of 2015 is rather short term for Fool investing.

- ###### Report this Comment On December 28, 2014, at 8:02 PM, Trololololo wrote:

  Regarding the recommendations of the MF staff, my biggest concern for each of these have to do with valuation, especially at this stage of the bull market. Facebook is a good example. Despite its growth and promise, Facebook trades at a very high earnings multiple and PEG, something I found with many of the recommendations above.

  Yes, I know. You can't judge a business by its earnings alone. But something that increasingly worries me about so many MF recommendations is that I read nothing but "feel-good movie of the summer!!!" stories tied to them without a close look on whether their growth will ever catch up to the PE applied to them by the market. It might be one thing when a bull market is just getting its legs. But I am concerned that we are getting into the latter stages of a remarkable rally. And at some point, the party will end, and the seas will roll back, letting us see who was swimming naked.

  Call me wrong and point me to the errors in my ways. But when I first joined the Motley Fool, I did so because the Gardner brothers pounded the table on the notion of not paying too much for an investment in the style of Graham, Dodd and Buffett. Today however I am left with the impression that the hierarchy of the Motley Fool does not think this is important. And that deeply concerns me.

  Don't get me wrong – I'm all for growth, but at a reasonable price. And the recommendations above, excellent companies notwithstanding, appear to be far too rich for my blood.

  FOOLS: Please reply with your thoughts. I'm not afraid of criticism; in fact, quite the opposite. It's an opportunity to learn from you. Thanks in advance.

- ###### Report this Comment On December 28, 2014, at 8:35 PM, EvanBuck wrote:

  @Trololololo: Your comment is remarkably insightful for someone with such a..."non-serious" username.

- ###### Report this Comment On December 28, 2014, at 10:29 PM, phexac wrote:

  Trololololo, I am right there with you. I canceled my SA subscription because the methodology for recommendations becomes complete garbage. There was no sign of analysis or consideration given to what price is ok to pay for a particular stock, and more and more recommendations were trending towards momentum overhyped story stocks with earnings multiples in the stratosphere. Moreover, those stocks were implied as good buys at any price and at any stage of the hype cycle.

  Furthermore, if you look at the prices of SA recommendations and replace each recommended stock buy with S&P 500, then since 2011, SA has underperformed the market by a significant margin.

  MOREOVER, when you looked at the stock price history of the SA picks, you also saw those stocks could not be obtained for the prices listed in the SA recommendation history, as in most cases prices that low did not occur for weeks either before or after the recommendations. This last part is a huge deal since it basically means that SA subscribers can never ever even approach the advertised SA results because the performance advertised for the service is based on prices that didn't exist at the time of recommendations. In many cases the in listed purchase price was over 10% lower than the bottom of the range for the stock price for several weeks before or after the recommendation date.

  So due to the "methodology" based on feel good stories, reported under performance, and very importantly outright lies as to the prices for their picks, I saw this service for what it is--one that is completely worthless and trying to sell lucky picks of NFLX and AMZN 10+ years ago as some ability to stock pick well.

  Bottom line is, I agree with you, MF writers' methodology for recommending stocks is worthless as are the services they offer.

- ###### Report this Comment On December 29, 2014, at 9:17 AM, bloomr wrote:

  Purchase prices are dividend-adjusted, as is the S&P benchmark comparison. I have been a Fool reader for over 15 years, and I have not seen any shenanigans with their purchase price claims. They also wait to buy a stock for at least a day after they recommend it, so they don't take advantage of the "bump" some stocks get on the day of the rec.

- ###### Report this Comment On December 29, 2014, at 10:18 AM, phexac wrote:

  Bloom, as I mentioned in my post, the prices they list often don't occur for weeks before or after the recommendation, so a short waiting period is definitely not in play here.

  The S&P price is accurate usually though, so for my money, there is definitely shenanigans going on.

  And even with those, since start of 2011, their picks have underperformed the market.

- ###### Report this Comment On December 29, 2014, at 11:13 AM, TMFBomb wrote:

  @Trololololo, phexac, and bloomr,

  In terms of stock selection, The Motley Fool believes in finding great companies and investing for the long term (years and decades, not days and months) and that market timing doesn't work. We also believe in listening to a diversity of opinion...that means we can disagree with each other...for instance, the analysts who contributed to this article can disagree with each other and can disagree with the analysts on our premium services like Motley Fool Stock Advisor.

  One person's overvalued stock based on a high P/E ratio is another person's undervalued stock because of the belief in factors such as future growth, a strong moat enabling sustainability of earnings and market relevance, a misunderstood accounting nuance, a one-time item, etc.

  Because opinions and strategies differ, we focus on being highly transparent with our premium picks, including maintaining a scorecard of every pick's performance vs. the S&P 500. We take the integrity of that reporting very seriously. Here is what we say in our FAQ for Motley Fool Stock Advisor members:

  "How do you track the performance of the stocks you recommend?

  We provide a scorecard of comprehensive performance data online. The scorecard tracks both active stocks and ones we’ve recommended selling — look for sold stocks in the David vs. Tom view of the online scorecard.

  As of Jan. 26, 2011, we use total average returns on our scorecard. Total average returns are the average of all individual stock recommendations (active and sold) and the average of the S&P 500 Total Return Index, starting from the end of the day we make each recommendation. Both the stock and benchmark returns include reinvested dividends, splits, and adjustments for other corporate actions such as spinoffs and acquisitions, if applicable.

  On the David vs. Tom comparison page, the column “vs. S&P” is calculated by taking the difference in the return of the recommendation and the return of the S&P 500 over the same period. It's measured in percentage points.

  Our returns are verified by Alpha Performance Verification Services"

  The link to their latest report is here:

  http://g.fool.com/art/newsletters/18/images/The%20Motley%20F...

  Fool on,

  Anand Chokkavelu, CFA (Editorial Director of Fool.com)

- ###### Report this Comment On December 29, 2014, at 12:15 PM, phexac wrote:

  You can tell by the lack of actual denial in Bomb's post of the practice mismatching the price of stock picks with the recommendation date price I described above in Bomb's that their price point picking is exactly as I described.

  "One person's overvalued stock based on a high P/E ratio is another person's undervalued stock because of the belief in factors such as future growth"

  This is the typical nebulous declaration followed by an SA stock pick based on more fuzzy feeling about how fantastic a company is and completely ignoring that price you pay for a security is one of the most important factors in determining returns.

  I suggest anyone with SA subscription go to the page with recommendation and do your own research. See if the price on recommendation date is within the range where stock traded on or around that date. Then check the returns against actual obtainable stock price vs S&P. Then see how SA has done since 2011. Then see how SA has done if you take out AMZN and NFLX from early 2000s. You will see that what's left is a bunch of mediocre picks based on nebulous beliefs that are pretty average.

  And just one more time, any stock advising service that treats a stock as equally good buy regardless of price (often different by a factor) is worse than worthless.

  Just look at DDD, which SA touted from about $18 all the way to $80+ post stock split. If you bought at 18, sure it was ok, though not spectacular. If you bought at 80, over half of your money is gone.

  Price matters and by acting like it doesn't MF team is basically insulting everyone's intelligence.

- ###### Report this Comment On December 29, 2014, at 12:30 PM, phexac wrote:

  Oh and when someone tells you, our results are verified by XYZ, it's a meaningless statement unless you know exactly what's being verified and what the process is. Judging by the TFM response, it's not the type of verification that would do anything about using prices on dates different from the recommendations.

  And the thing is, if it were the case TMF just buys the stock on some other date for operational reasons, that's fine, but you would expect roughly half the prices to be above and half below the recommend on date price range. However, in SA case, the prices I checked for 2011 and 2012 are ALWAYS lower than on the recommendation date.

  When you see something like this, you know you are being lied to.

- ###### Report this Comment On December 29, 2014, at 12:46 PM, Mathman6577 wrote:

  ^^^ No matter what TMFBomb said (and in many cases other Fools have said in the past) in his comment, many of the Fools still pick their stocks based upon personal opinions regarding the company, the CEO, or a political agenda (which is becoming more and more prevalent).

  If it meets their green energy (solar and wind), ObamaCare, min. wage, or income inequality narrative expect Fools to weigh in positively, even if the P/E is at 200 or the company has never made any money.

  If the CEO is a golden boy or girl in their eyes the stock is automatically a recommendation (Jeff Bezos can do no wrong -- even if AMZN doesn't turn a profit they will make excuses such as the "company is planning for the future").

  If the company goes against their narrative (think WMT, MCD, and many big oil companies) the stock gets bashed.

  Apple products are always being compared against "superior" Android products on one or two features (that most users do not care about). The forest is always missed thru the trees when it comes to Apple.

- ###### Report this Comment On December 29, 2014, at 4:52 PM, AaronRogers wrote:

  LOL! So everyone is bombing MF on how they calculate their scoring. I am and so should everyone else be confident in how they score their picks. Its a very simple calculation. They don't always hype themselves. Hidden Gems showed a lesser return for quite a while.

  However, I definitely agree with the poster with regard to the divergence away from graham style. I don't think MF has because of lack of principle but rather more simplistic explanations and articles. I would like to see MF get back to their more complicated articles that require research to completely follow. The conclusion paragraph works well for those who just want a quick answer to what picks and why. However, I feel MF used to challenge us as readers to learn more and teach more. If they are recommending sky high P/E stocks they should type more explaining that the growth rates show an expanded P/E is worthwhile and what is considered to be a reasonable ratio of growth rate to P/E. The articles have become more USA Today like is basically what I'm saying. The banking/black swan article is a great example of a great article. I actually have to look up the exact ratio and how it is calculated. However, it was in depth and educational while challenging and provided a quirky and interesting twist on investments within the sector.

  However, I think everyone can trust how they score their advice and picks.

  What I don't like about these picks is how bland and generic can they be. Its impossible for Apple to be a true top stock. Way to BIG with no new tech. to be ground breaking and dominant. MF used to find more obscure and perhaps more risky companies.

- ###### Report this Comment On December 29, 2014, at 5:31 PM, phexac wrote:

  Yeah, it's definitely the lack of deeper research that is a turn-off for me.

- ###### Report this Comment On December 29, 2014, at 5:32 PM, phexac wrote:

  That being said, their prices are factually off. How you choose to interpret that or whether you even take it into consideration is up to you.

- ###### Report this Comment On December 30, 2014, at 12:08 AM, bloomr wrote:

  phexac, please give an example of what you consider an erroneous price quote. I'd be willing to bet it's because of adjustments down the road - dividends, spin offs, acquisitions, etc.

- ###### Report this Comment On December 30, 2014, at 1:29 AM, phexac wrote:

  bloom, what I did was start in 2011. Go to the first recommendation. Check out the date and the price. Next go to Google or Yahoo finance and see what was the price range where the stock traded on that date. Is MF price even within that range?

  In cases where it isn't, go ahead and see when is the closest day preceding or following the recommendation date when the advertised price occurred.

  And remember, in most cases Google and Yahoo also adjust their stock prices correctly.

- ###### Report this Comment On January 01, 2015, at 10:10 PM, anastunya wrote:

  I would never buy food from a country that killed its own babies with poisonous formula. Many Americans are avoiding anything made in China.

- ###### Report this Comment On January 02, 2015, at 1:10 AM, Foolistherule wrote:

  Phexac, AaronRogers, and Trololo..

  Interested in the style of Graham, Dodd, Buffet, and Lynch?

  So am I !!

  So, I invite you all to check out this project that we are working on for quite a few busy weeks now.

  I gotta warn you, it is not for the weak. We are doing 'hard core' write ups of lots of stocks. So far, we have compiled a list of more than 100 stocks small caps to large. Value or growth. Divs or not. A little bit of 'deep value' (oil stocks right now).

  It is a HUGE thread. Don't try to read it all. Start at the bottom. We are all serious investors, but we joke and have fun.

  Tell ya what:

  Check in at the end of the thread. Stop by and say 'hi'. Let me know what you are after and I'll

  guide you to the right spot. Or, better yet, join us in our quest to seek out the best stocks in Fooldom!

  This could be just the spot you are lookind for if you miss 'the good ol days' of SA

  See ya there!--

  http://www.fool.com/investing/general/2014/11/02/4-secrets-w...

##### Add your comment.

Your Fool username will be displayed with your comment.
Please be respectful with your comments. Review our Fool's Rules.

Your comment may be delayed up to 15 minutes

### Compare Brokers

Fool Disclosure

### Sponsored Links

Leaked: Apple's Next Smart Device
(Warning, it may shock you)
The secret is out... experts are predicting 458 million of these types of devices will be sold per year. 1 hyper-growth company stands to rake in maximum profit - and it's NOT Apple. Show me Apple's new smart gizmo!

DocumentId: 3208784, ~/Articles/ArticleHandler.aspx, 1/3/2015 6:47:11 AM

### Report This Comment

Use this area to report a comment that you believe is in violation of the community guidelines. Our team will review the entry and take any appropriate action.

### Sending report...

### Today's Market

updated 8 hours ago Sponsored by:
| DOW | 17,832.99 | 9.92 | 0.06%
| S&P 500 | 2,058.20 | -0.70 | -0.03%
| NASD | 4,726.81 | -9.24 | -0.20%

### Create My Watchlist

Go to My Watchlist

##### You don't seem to be following any stocks yet!

Better investing starts with a watchlist. Now you can create a personalized watchlist and get immediate access to the personalized information you need to make successful investing decisions.

Data delayed up to 5 minutes

### Most Popular Articles

1. Foolanthropy 2014
2. The Market's 10 Best Stocks
3. 122 Things About Investing
4. 7 Stocks to Buy for 2015
5. Investing in Japan?

### Related Tickers

1/2/2015 4:00 PM

AAPL | $109.33 |  | -1.05 | -0.95%
Apple | CAPS Rating:

FB | $78.45 |  | +0.43 | +0.55%
Facebook | CAPS Rating:

GOOG | $524.81 |  | -1.59 | -0.30%
Google (C shares) | CAPS Rating:

GOOGL | $529.55 |  | -1.11 | -0.21%
Google (A shares) | CAPS Rating:

QCOM | $74.28 |  | -0.05 | -0.07%
Qualcomm | CAPS Rating:

SEAS | $17.97 |  | +0.07 | +0.39%
SeaWorld Entertain… | CAPS Rating:

TSM | $22.28 |  | -0.10 | -0.45%
Taiwan Semiconduct… | CAPS Rating:

Article Preview — For full access, register below, it's free
To keep reading, click here, it's free or login here